@@ -1,45 +1,52 @@
 #
 # This file is part of ElasticSearchX-Model
 #
-# This software is Copyright (c) 2013 by Moritz Onken.
+# This software is Copyright (c) 2015 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Bulk;
-{
-  $ElasticSearchX::Model::Bulk::VERSION = '0.1.7';
-}
+$ElasticSearchX::Model::Bulk::VERSION = '0.1.8';
+use Search::Elasticsearch::Bulk;
 use Moose;
 
 has stash => (
     is      => 'ro',
-    traits  => ['Array'],
-    handles => { add => 'push', stash_size => 'count' },
-    default => sub { [] },
+    isa => "Search::Elasticsearch::Bulk",
+    handles => { stash_size => '_buffer_count', commit => "flush" },
+    lazy_build => 1,
 );
 has size => ( is => 'ro', isa => 'Int', default => 100 );
 has es => ( is => 'ro' );
 
+sub _build_stash {
+    my $self = shift;
+    $self->es->bulk_helper( max_count => $self->size );
+}
+
+sub add {
+    my ($self, $action, $payload) = (shift, %{$_[0]});
+    $payload->{source} = delete $payload->{body};
+    $self->stash->add_action($action => $payload);
+}
+
 sub update {
     my ( $self, $doc, $qs ) = @_;
     $self->add( { index => ref $doc eq 'HASH' ? $doc : { $doc->_put( $doc->_update($qs) ) } } );
-    $self->commit if ( $self->stash_size > $self->size );
     return $self;
 }
 
 sub create {
     my ( $self, $doc, $qs ) = @_;
     $self->add( { create => ref $doc eq 'HASH' ? $doc : { $doc->_put($qs) } } );
-    $self->commit if ( $self->stash_size > $self->size );
     return $self;
 }
 
 sub put {
     my ( $self, $doc, $qs ) = @_;
     $self->add( { index => ref $doc eq 'HASH' ? $doc : { $doc->_put, %{ $qs || {} } } } );
-    $self->commit if ( $self->stash_size > $self->size );
     return $self;
 }
 
@@ -54,21 +61,12 @@ sub delete {
             }
         }
     );
-    $self->commit if ( $self->stash_size > $self->size );
     return $self;
 }
 
-sub commit {
-    my $self = shift;
-    return unless ( $self->stash_size );
-    my $result = $self->es->bulk( $self->stash );
-    $self->clear;
-    return $result;
-}
-
 sub clear {
     my $self = shift;
-    @{ $self->stash } = ();
+    $self->stash->clear_buffer;
     return $self;
 }
 
@@ -90,7 +88,7 @@ ElasticSearchX::Model::Bulk
 
 =head1 VERSION
 
-version 0.1.7
+version 0.1.8
 
 =head1 SYNOPSIS
 
@@ -104,7 +102,7 @@ version 0.1.7
 
 =head1 DESCRIPTION
 
-This class is a wrapper around L<ElasticSearch/bulk()> which adds
+This class is a wrapper around L<Search::Elasticsearch::Bulk> which adds
 some convenience. By specifiying a L</size> you set the maximum
 number of documents that are processed in one request. You can either
 L</put> or L</delete> documents. Once the C<$bulk> object is out
@@ -128,7 +126,7 @@ gets out of scope or if you call L</commit> explicitly.
 
 =head2 es
 
-The L<ElasticSearch> object.
+The L<Search::Elasticsearch> object.
 
 =head1 METHODS
 
@@ -167,7 +165,7 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Moritz Onken.
+This software is Copyright (c) 2015 by Moritz Onken.
 
 This is free software, licensed under:
 
