@@ -1,16 +1,14 @@
 #
 # This file is part of ElasticSearchX-Model
 #
-# This software is Copyright (c) 2013 by Moritz Onken.
+# This software is Copyright (c) 2015 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Document::Role;
-{
-  $ElasticSearchX::Model::Document::Role::VERSION = '0.1.7';
-}
+$ElasticSearchX::Model::Document::Role::VERSION = '0.1.8';
 use Moose::Role;
 use ElasticSearchX::Model::Util ();
 use JSON;
@@ -90,7 +88,8 @@ sub _create {
 
 sub put {
     my ( $self, $qs ) = @_;
-    my $return = $self->index->model->es->index( $self->_put($qs) );
+    my $method = $qs && ref $qs eq "HASH" && (delete $qs->{create}) ? "create" : "index";
+    my $return = $self->index->model->es->$method( $self->_put($qs) );
     $self->_clear_loaded_attributes;
     my $id     = $self->meta->get_id_attribute;
     $id->set_value( $self, $return->{_id} ) if ($id);
@@ -110,7 +109,7 @@ sub _put {
         index => $self->index->name,
         type  => $self->meta->short_name,
         $id ? ( id => $id ) : (),
-        data => $data,
+        body => $data,
         $parent ? ( parent => $parent->get_value($self) ) : (),
         %$qs,
     );
@@ -152,7 +151,7 @@ ElasticSearchX::Model::Document::Role
 
 =head1 VERSION
 
-version 0.1.7
+version 0.1.8
 
 =head1 AUTHOR
 
@@ -160,7 +159,7 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Moritz Onken.
+This software is Copyright (c) 2015 by Moritz Onken.
 
 This is free software, licensed under:
 
