@@ -1,17 +1,14 @@
 #
 # This file is part of ElasticSearchX-Model
 #
-# This software is Copyright (c) 2013 by Moritz Onken.
+# This software is Copyright (c) 2015 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Document::Trait::Attribute;
-{
-  $ElasticSearchX::Model::Document::Trait::Attribute::VERSION = '0.1.7';
-}
-
+$ElasticSearchX::Model::Document::Trait::Attribute::VERSION = '0.1.8';
 # ABSTRACT: Trait that extends the meta class of a document class
 use Moose::Role;
 use ElasticSearchX::Model::Document::Mapping;
@@ -39,6 +36,15 @@ has property          => ( is => 'ro', isa => 'Bool', default => 1 );
 has query_property    => ( is => 'ro', isa => 'Bool', default => 0 );
 has field_name =>
     ( is => 'ro', isa => 'Str', lazy => 1, default => sub { shift->name } );
+has isa_arrayref =>
+    ( is => 'ro', lazy => 1, isa => 'Bool', builder => '_build_isa_arrayref' );
+
+sub _build_isa_arrayref {
+    my $self = shift;
+    my $tc = $self->type_constraint;
+    return 0 unless $tc;
+    return $tc->is_a_type_of("ArrayRef");
+}
 
 sub build_property {
     my $self = shift;
@@ -54,7 +60,6 @@ before _process_options => sub {
     %$options = ( builder => 'build_id', lazy => 1, %$options )
         if ( $options->{id} && ref $options->{id} eq 'ARRAY' );
 
-    #$options->{required} = 1 if($options->{id});
     $options->{traits} ||= [];
     push(
         @{ $options->{traits} },
@@ -108,7 +113,7 @@ ElasticSearchX::Model::Document::Trait::Attribute - Trait that extends the meta
 
 =head1 VERSION
 
-version 0.1.7
+version 0.1.8
 
 =head1 ATTRIBUTES
 
@@ -240,7 +245,7 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Moritz Onken.
+This software is Copyright (c) 2015 by Moritz Onken.
 
 This is free software, licensed under:
 
