@@ -1,20 +1,17 @@
 #
 # This file is part of ElasticSearchX-Model
 #
-# This software is Copyright (c) 2013 by Moritz Onken.
+# This software is Copyright (c) 2015 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Document::Types;
-{
-  $ElasticSearchX::Model::Document::Types::VERSION = '0.1.7';
-}
+$ElasticSearchX::Model::Document::Types::VERSION = '0.1.8';
 use List::MoreUtils ();
 use DateTime::Format::Epoch::Unix;
 use DateTime::Format::ISO8601;
-use ElasticSearch;
 use MooseX::Attribute::Deflator;
 use MooseX::Attribute::Deflator::Moose;
 use DateTime;
@@ -194,7 +191,7 @@ ElasticSearchX::Model::Document::Types
 
 =head1 VERSION
 
-version 0.1.7
+version 0.1.8
 
 =head1 AUTHOR
 
@@ -202,7 +199,7 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Moritz Onken.
+This software is Copyright (c) 2015 by Moritz Onken.
 
 This is free software, licensed under:
 
