@@ -1,16 +1,14 @@
 #
 # This file is part of ElasticSearchX-Model
 #
-# This software is Copyright (c) 2013 by Moritz Onken.
+# This software is Copyright (c) 2015 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Index;
-{
-  $ElasticSearchX::Model::Index::VERSION = '0.1.7';
-}
+$ElasticSearchX::Model::Index::VERSION = '0.1.8';
 use Moose;
 use Module::Find ();
 use Class::Load  ();
@@ -116,12 +114,12 @@ sub deployment_statement {
 
 sub refresh {
     my $self = shift;
-    $self->es->refresh_index( index => $self->name );
+    $self->es->indices->refresh( index => $self->name );
 }
 
 sub delete {
     my $self = shift;
-    $self->es->delete_index( index => $self->name );
+    $self->es->indices->delete( index => $self->name );
 }
 
 __PACKAGE__->meta->make_immutable( inline_constructor => 0 );
@@ -138,7 +136,7 @@ ElasticSearchX::Model::Index
 
 =head1 VERSION
 
-version 0.1.7
+version 0.1.8
 
 =head1 ATTRIBUTES
 
@@ -229,7 +227,7 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Moritz Onken.
+This software is Copyright (c) 2015 by Moritz Onken.
 
 This is free software, licensed under:
 
