@@ -1,18 +1,16 @@
 #
 # This file is part of ElasticSearchX-Model
 #
-# This software is Copyright (c) 2013 by Moritz Onken.
+# This software is Copyright (c) 2015 by Moritz Onken.
 #
 # This is free software, licensed under:
 #
 #   The (three-clause) BSD License
 #
 package ElasticSearchX::Model::Role;
-{
-  $ElasticSearchX::Model::Role::VERSION = '0.1.7';
-}
+$ElasticSearchX::Model::Role::VERSION = '0.1.8';
 use Moose::Role;
-use ElasticSearch;
+use Search::Elasticsearch;
 use ElasticSearchX::Model::Index;
 use version;
 use ElasticSearchX::Model::Document::Types qw(ES);
@@ -20,46 +18,46 @@ use ElasticSearchX::Model::Document::Types qw(ES);
 has es => ( is => 'rw', lazy_build => 1, coerce => 1, isa => ES );
 
 sub _build_es {
-    ElasticSearch->new(
-        servers   => '127.0.0.1:9200',
-        transport => 'http',
-        timeout   => 30,
+    Search::Elasticsearch->new(
+        nodes     => $ENV{ES}||'127.0.0.1:9200',
+        cxn     => 'HTTPTiny',
     );
 }
 
 sub deploy {
     my ( $self, %params ) = @_;
     my $t = $self->es->transport;
+
     foreach my $name ( $self->meta->get_index_list ) {
         my $index = $self->index($name);
         next if ( $index->alias_for && $name eq $index->alias_for );
         $name = $index->alias_for if ( $index->alias_for );
         local $@;
         eval {
-            $t->request( { method => 'DELETE', cmd => "/$name" } )
+            $self->es->indices->delete( index => $name )
         } if ( $params{delete} );
         my $dep     = $index->deployment_statement;
         my $mapping = delete $dep->{mappings};
         eval {
-            $t->request(
+            $t->perform_request(
                 {   method => 'PUT',
-                    cmd    => "/$name",
-                    data   => $dep,
+                    path   => "/$name",
+                    body   => $dep,
                 }
             );
         };
         sleep(1);
         while ( my ( $k, $v ) = each %$mapping ) {
-            $t->request(
+            $t->perform_request(
                 {   method => 'PUT',
-                    cmd    => "/$name/$k/_mapping",
-                    data   => { $k => $v },
+                    path   => "/$name/$k/_mapping",
+                    body   => { $k => $v },
                 }
             );
         }
         if ( my $alias = $index->alias_for ) {
             my @aliases
-                = keys %{ $self->es->get_aliases( index => $index->name, ignore_missing => 1 )
+                = keys %{ $self->es->indices->get_aliases( index => $index->name, ignore => [404] )
                     || {} };
             my $actions = [
                 (   map {
@@ -68,7 +66,7 @@ sub deploy {
                 ),
                 { add => { index => $alias, alias => $index->name } }
             ];
-            $self->es->aliases( actions => $actions );
+            $self->es->indices->update_aliases( body => { actions => $actions } );
         }
     }
     return 1;
@@ -81,7 +79,7 @@ sub bulk {
 
 sub es_version {
     my $self = shift;
-    my $string = $self->es->current_server_version->{number};
+    my $string = $self->es->info->{version}->{number};
     $string =~ s/RC//g;
     return version->parse( $string )->numify;
 }
@@ -100,7 +98,7 @@ ElasticSearchX::Model::Role
 
 =head1 VERSION
 
-version 0.1.7
+version 0.1.8
 
 =head1 AUTHOR
 
@@ -108,7 +106,7 @@ Moritz Onken
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2013 by Moritz Onken.
+This software is Copyright (c) 2015 by Moritz Onken.
 
 This is free software, licensed under:
 
